@@ -57,17 +57,21 @@ explicit state management.
 """
 
 from abc import ABC, abstractmethod
-from typing import Optional, Union, Tuple, Any, Dict, List
+from typing import Optional, Union, Tuple, Any, Dict, List, TYPE_CHECKING
 from pathlib import Path
 import numpy as np
 
+if TYPE_CHECKING:
+    from ..datamodule import KDFMDataModule, DFMDataModule, DDFMDataModule
+
 from ..config import (
     DFMConfig, make_config_source, ConfigSource,
     BaseResult
 )
-from ..config.constants import DEFAULT_BLOCK_NAME
+from ..config.constants import DEFAULT_BLOCK_NAME, DEFAULT_DTYPE, DEFAULT_FORECAST_HORIZON, MAX_WARNING_ITEMS, MAX_ERROR_ITEMS, DEFAULT_CLOCK_FREQUENCY
 from ..logger import get_logger
 from ..utils.errors import ConfigurationError, ModelNotTrainedError, ModelNotInitializedError
+from ..utils.validation import check_has_attr
 
 _logger = get_logger(__name__)
 
@@ -110,8 +114,9 @@ class BaseFactorModel(ABC):
         ConfigurationError
             If model configuration has not been set
         """
-        if not hasattr(self, '_config') or self._config is None:
-            model_type = self.__class__.__name__
+        model_type = self.__class__.__name__
+        check_has_attr(self, '_config', model_type, error_class=ConfigurationError)
+        if self._config is None:
             raise ConfigurationError(
                 f"{model_type} config access failed: model configuration has not been set",
                 details="Please call load_config() or pass config to __init__() first"
@@ -128,7 +133,8 @@ class BaseFactorModel(ABC):
         """
         if self._result is None:
             # Try to extract result from training state if available
-            if hasattr(self, 'training_state') and self.training_state is not None:
+            training_state = getattr(self, 'training_state', None)
+            if training_state is not None:
                 try:
                     self._result = self.get_result()
                     return
@@ -157,7 +163,6 @@ class BaseFactorModel(ABC):
         if block_name is None:
             block_name = DEFAULT_BLOCK_NAME
         
-        from ..config.constants import DEFAULT_CLOCK_FREQUENCY
         return DFMConfig(
             frequency={'temp': DEFAULT_CLOCK_FREQUENCY},
             blocks={block_name: {'factors': 1, 'ar_lag': 1, 'clock': 'm'}}
@@ -189,8 +194,6 @@ class BaseFactorModel(ABC):
         yaml: Optional[Union[str, Path]] = None,
         mapping: Optional[Dict[str, Any]] = None,
         hydra: Optional[Union[Dict[str, Any], Any]] = None,
-        base: Optional[Union[str, Path, Dict[str, Any], ConfigSource]] = None,
-        override: Optional[Union[str, Path, Dict[str, Any], ConfigSource]] = None,
     ) -> DFMConfig:
         """Common config loading logic shared by all models."""
         config_source = make_config_source(
@@ -198,17 +201,13 @@ class BaseFactorModel(ABC):
             yaml=yaml,
             mapping=mapping,
             hydra=hydra,
-            base=base,
-            override=override,
         )
         
-        # All ConfigSource implementations use .load() method
         new_config = config_source.load()
-        
         self._config = new_config
         return new_config
     
-    def _get_datamodule(self) -> Any:  # type: ignore[return]  # Returns Union[KDFMDataModule, DFMDataModule, DDFMDataModule] but Any avoids circular imports
+    def _get_datamodule(self) -> Union['KDFMDataModule', 'DFMDataModule', 'DDFMDataModule']:
         """Get DataModule from model or trainer.
         
         This method attempts to retrieve the DataModule from:
@@ -218,12 +217,9 @@ class BaseFactorModel(ABC):
         This is a common helper used by predict() methods to access data preprocessing
         parameters (Mx, Wx) and target series configuration.
         
-        **Type Note**: Returns `Any` to avoid circular imports. Actual return type is
-        `Union[KDFMDataModule, DFMDataModule, DDFMDataModule]` depending on model type.
-        The `# type: ignore[return]` comment suppresses the type checker warning.
-        This is a known limitation due to circular import constraints - the return type
-        is type-safe at runtime but cannot be expressed in the type system without
-        circular dependencies.
+        **Type Note**: Uses TYPE_CHECKING to avoid circular imports. The return type
+        is `Union[KDFMDataModule, DFMDataModule, DDFMDataModule]` depending on model type.
+        TYPE_CHECKING allows proper type hints without runtime circular dependencies.
         
         Returns
         -------
@@ -246,13 +242,15 @@ class BaseFactorModel(ABC):
         --------
         >>> # After trainer.fit(), DataModule is available from trainer
         >>> data_module = model._get_datamodule()
-        >>> Mx, Wx = data_module.get_std_params()
-        >>> target_series = data_module.get_target_series()
+        >>> target_series = data_module.target_series
+        >>> target_scaler = data_module.target_scaler
         """
         data_module = getattr(self, '_data_module', None)
         
-        if data_module is None and hasattr(self, 'trainer') and self.trainer is not None:
-            data_module = getattr(self.trainer, 'datamodule', None)
+        if data_module is None:
+            trainer = getattr(self, 'trainer', None)
+            if trainer is not None:
+                data_module = getattr(trainer, 'datamodule', None)
         
         if data_module is None:
             raise ModelNotInitializedError(
@@ -265,24 +263,46 @@ class BaseFactorModel(ABC):
             )
         return data_module
     
+    @staticmethod
+    def _validate_ndarray(arr: Any, name: str, expected_ndim: int) -> None:
+        """Validate a numpy array has expected number of dimensions.
+        
+        Parameters
+        ----------
+        arr : Any
+            Array to validate
+        name : str
+            Name of the array for error messages
+        expected_ndim : int
+            Expected number of dimensions
+            
+        Raises
+        ------
+        DataValidationError
+            If array is not a numpy array or has wrong number of dimensions
+        """
+        from ..utils.errors import DataValidationError
+        if not isinstance(arr, np.ndarray) or arr.ndim != expected_ndim:
+            raise DataValidationError(
+                f"{name} must be {expected_ndim}D numpy array, got shape {arr.shape if isinstance(arr, np.ndarray) else 'not array'}"
+            )
+    
     def _forecast_var_factors(
         self,
         Z_last: np.ndarray,
         A: np.ndarray,
-        p: int,
-        horizon: int,
+        p: int = 1,
+        horizon: int = 1,
         Z_prev: Optional[np.ndarray] = None
     ) -> np.ndarray:
-        """Forecast factors using VAR dynamics.
+        """Forecast factors using AR(1) dynamics.
         
-        Supports VAR(1) and VAR(2) factor dynamics (maximum supported order is VAR(2)).
         Uses iterative matrix multiplication for efficient computation.
         
-        **VAR(1) Dynamics**: f_t = A @ f_{t-1}
-        **VAR(2) Dynamics**: f_t = A1 @ f_{t-1} + A2 @ f_{t-2}
+        **AR(1) Dynamics**: f_t = A @ f_{t-1}
         
         This method is used by both KDFM and DDFM for factor forecasting, ensuring
-        consistent VAR dynamics computation across models.
+        consistent AR dynamics computation across models.
         
         Parameters
         ----------
@@ -290,18 +310,14 @@ class BaseFactorModel(ABC):
             Last factor state of shape (m,) where m is number of factors.
             Must be 1D array with m >= 1.
         A : np.ndarray
-            Transition matrix:
-            - For VAR(1): shape (m, m)
-            - For VAR(2): shape (m, 2m) where A[:, :m] = A1, A[:, m:] = A2
+            Transition matrix of shape (m, m) for AR(1).
             Must be 2D array with compatible dimensions.
-        p : int
-            VAR order. Must be 1 or 2 (maximum supported order is VAR(2)).
-            Values outside this range will raise ConfigurationError.
-        horizon : int
+        p : int, default 1
+            AR order (always 1).
+        horizon : int, default 1
             Number of periods to forecast. Must be >= 1.
         Z_prev : np.ndarray, optional
-            Previous factor state for VAR(2) of shape (m,). Required if p == 2.
-            If None and p == 2, falls back to VAR(1) dynamics.
+            Ignored (unused parameter).
             
         Returns
         -------
@@ -312,8 +328,6 @@ class BaseFactorModel(ABC):
             
         Raises
         ------
-        ConfigurationError
-            If VAR order p is not 1 or 2 (unsupported order)
         DataValidationError
             If input shapes are incompatible or invalid
         NumericalError
@@ -322,9 +336,10 @@ class BaseFactorModel(ABC):
             
         Examples
         --------
-        >>> # VAR(1) forecast
+        >>> # AR(1) forecast
+        >>> from dfm_python.numeric.stability import create_scaled_identity
         >>> Z_last = np.array([1.0, 2.0, 3.0])  # 3 factors
-        >>> A = np.eye(3) * 0.9  # Stable transition matrix
+        >>> A = create_scaled_identity(3, 0.9)  # Use helper function for scaled identity
         >>> Z_forecast = model._forecast_var_factors(Z_last, A, p=1, horizon=5)
         >>> assert Z_forecast.shape == (5, 3)
         """
@@ -332,14 +347,8 @@ class BaseFactorModel(ABC):
         from ..numeric.validator import validate_no_nan_inf
         
         # Validate inputs
-        if not isinstance(Z_last, np.ndarray) or Z_last.ndim != 1:
-            raise DataValidationError(
-                f"Z_last must be 1D numpy array, got shape {Z_last.shape if isinstance(Z_last, np.ndarray) else 'not array'}"
-            )
-        if not isinstance(A, np.ndarray) or A.ndim != 2:
-            raise DataValidationError(
-                f"A must be 2D numpy array, got shape {A.shape if isinstance(A, np.ndarray) else 'not array'}"
-            )
+        self._validate_ndarray(Z_last, "Z_last", 1)
+        self._validate_ndarray(A, "A", 2)
         
         m = Z_last.shape[0]
         if m < 1:
@@ -351,253 +360,86 @@ class BaseFactorModel(ABC):
         validate_no_nan_inf(Z_last, name="Z_last")
         validate_no_nan_inf(A, name="transition matrix A")
         
+        # Helper function to validate array shape consistently
+        def _validate_shape(
+            array: np.ndarray,
+            expected_shape: Tuple[int, ...],
+            name: str
+        ) -> None:
+            """Validate array has expected shape.
+            
+            Args:
+                array: Array to validate
+                expected_shape: Expected shape tuple
+                name: Name of array for error message
+            """
+            if array.shape != expected_shape:
+                raise DataValidationError(
+                    f"{name} must have shape {expected_shape}, got {array.shape}"
+                )
+        
         if Z_prev is not None:
             validate_no_nan_inf(Z_prev, name="Z_prev")
-            if Z_prev.shape != (m,):
-                raise DataValidationError(
-                    f"Z_prev must have shape ({m},), got {Z_prev.shape}"
-                )
+            _validate_shape(Z_prev, (m,), "Z_prev")
+        
+        # Helper function to handle forecast computation errors consistently
+        def _handle_forecast_error(
+            error: Exception,
+            error_message: str,
+            error_details: str,
+            exceptions_to_re_raise: Tuple[Any, ...]
+        ) -> None:
+            """Handle forecast computation errors consistently.
+            
+            Args:
+                error: The exception that occurred
+                error_message: Main error message
+                error_details: Detailed diagnostic information
+                exceptions_to_re_raise: Tuple of exception types to re-raise without wrapping
+            """
+            if isinstance(error, exceptions_to_re_raise):
+                raise
+            raise NumericalError(
+                error_message,
+                details=error_details
+            ) from error
+        
         try:
-            if p == 1:
-                # Validate VAR(1) shape
-                if A.shape != (m, m):
-                    raise DataValidationError(
-                        f"For VAR(1), A must have shape ({m}, {m}), got {A.shape}"
-                    )
-                
-                # VAR(1): f_t = A @ f_{t-1}
-                Z_forecast = np.zeros((horizon, m), dtype=np.float64)
-                Z_forecast[0, :] = A @ Z_last
-                for h in range(1, horizon):
-                    Z_forecast[h, :] = A @ Z_forecast[h - 1, :]
-                    
-            elif p == 2:
-                # Validate VAR(2) shape
-                if A.shape != (m, 2 * m):
-                    raise DataValidationError(
-                        f"For VAR(2), A must have shape ({m}, {2*m}), got {A.shape}"
-                    )
-                
-                # VAR(2): f_t = A1 @ f_{t-1} + A2 @ f_{t-2}
-                A1 = A[:, :m]
-                A2 = A[:, m:]
-                
-                if Z_prev is None:
-                    # Fallback to VAR(1) if not enough history
-                    Z_forecast = np.zeros((horizon, m), dtype=np.float64)
-                    Z_forecast[0, :] = A1 @ Z_last
-                    for h in range(1, horizon):
-                        Z_forecast[h, :] = A1 @ Z_forecast[h - 1, :]
-                else:
-                    Z_forecast = np.zeros((horizon, m), dtype=np.float64)
-                    Z_forecast[0, :] = A1 @ Z_last + A2 @ Z_prev
-                    if horizon > 1:
-                        Z_forecast[1, :] = A1 @ Z_forecast[0, :] + A2 @ Z_last
-                    for h in range(2, horizon):
-                        Z_forecast[h, :] = A1 @ Z_forecast[h - 1, :] + A2 @ Z_forecast[h - 2, :]
-            else:
-                raise ConfigurationError(
-                    f"{self.__class__.__name__} prediction failed: unsupported VAR order {p}",
-                    details="Maximum supported VAR order is VAR(2). Please use factor_order=1 (VAR(1)) or factor_order=2 (VAR(2))"
-                )
+            # AR(1) dynamics only (simplified)
+            # Validate AR(1) shape
+            _validate_shape(A, (m, m), "A (transition matrix)")
+            
+            # AR(1): f_t = A @ f_{t-1}
+            Z_forecast = np.zeros((horizon, m), dtype=DEFAULT_DTYPE)
+            Z_forecast[0, :] = A @ Z_last
+            for h in range(1, horizon):
+                Z_forecast[h, :] = A @ Z_forecast[h - 1, :]
             
             # Validate output
             validate_no_nan_inf(Z_forecast, name="forecasted factors")
-            
-            if Z_forecast.shape != (horizon, m):
-                raise DataValidationError(
-                    f"Forecast output has unexpected shape {Z_forecast.shape}, expected ({horizon}, {m})"
-                )
+            _validate_shape(Z_forecast, (horizon, m), "Forecast output")
             
             return Z_forecast
             
         except (RuntimeError, ValueError, TypeError, AttributeError, KeyError, IndexError) as e:
             # Specific exceptions for forecast computation failures
-            if isinstance(e, (ConfigurationError, DataValidationError)):
-                raise
-            raise NumericalError(
-                f"Forecast computation failed: {e}",
-                details=(
+            _handle_forecast_error(
+                error=e,
+                error_message=f"Forecast computation failed: {e}",
+                error_details=(
                     f"Z_last shape: {Z_last.shape}, A shape: {A.shape}, "
                     f"p={p}, horizon={horizon}. Check: (1) Matrix dimensions, "
                     f"(2) Numerical stability, (3) Input validity."
-                )
-            ) from e
+                ),
+                exceptions_to_re_raise=(ConfigurationError, DataValidationError)
+            )
     
-    def _transform_factors_to_observations(
-        self,
-        Z_forecast: np.ndarray,
-        C: np.ndarray,
-        Wx: Optional[np.ndarray] = None,
-        Mx: Optional[np.ndarray] = None
-    ) -> np.ndarray:
-        """Transform forecasted factors to observed series.
-        
-        This method applies the loading matrix to transform factors to observations,
-        then optionally unstandardizes the results using mean (Mx) and standard
-        deviation (Wx) parameters. This is a common operation used by KDFM, DFM, and DDFM
-        for converting factor forecasts to observation forecasts.
-        
-        **Transformation**: X = Z @ C^T
-        **Unstandardization**: X_original = X_standardized * Wx + Mx
-        
-        **Note**: If Wx is provided but Mx is None, Mx defaults to zeros (assumes
-        data was standardized with zero mean).
-        
-        Parameters
-        ----------
-        Z_forecast : np.ndarray
-            Forecasted factors of shape (horizon, m) where:
-            - horizon: Number of forecast periods
-            - m: Number of factors
-        C : np.ndarray
-            Loading matrix of shape (N, m) where:
-            - N: Number of observed variables
-            - m: Number of factors (must match Z_forecast.shape[1])
-        Wx : np.ndarray, optional
-            Standard deviation values for unstandardization of shape (N,).
-            If None, no unstandardization is applied (assumes data is already in original scale).
-        Mx : np.ndarray, optional
-            Mean values for unstandardization of shape (N,).
-            If None, no unstandardization is applied (assumes data is already in original scale).
-            Note: If Wx is provided but Mx is None, Mx defaults to zeros.
-            
-        Returns
-        -------
-        np.ndarray
-            Forecasted observations of shape (horizon, N) where:
-            - horizon: Number of forecast periods
-            - N: Number of observed variables (matches C.shape[0])
-            
-        Raises
-        ------
-        DataValidationError
-            If input shapes are incompatible or invalid
-        NumericalError
-            If transformation produces NaN/Inf values
-            
-        Examples
-        --------
-        >>> # Transform factors to observations
-        >>> Z_forecast = np.random.randn(5, 3)  # 5 periods, 3 factors
-        >>> C = np.random.randn(7, 3)  # 7 variables, 3 factors
-        >>> Wx = np.ones(7) * 10.0  # Standard deviations
-        >>> Mx = np.zeros(7)  # Means
-        >>> X_forecast = model._transform_factors_to_observations(Z_forecast, C, Wx, Mx)
-        >>> assert X_forecast.shape == (5, 7)
-        """
-        from ..utils.errors import DataValidationError, NumericalError
-        from ..numeric.validator import validate_no_nan_inf
-        
-        # Validate inputs
-        if not isinstance(Z_forecast, np.ndarray) or Z_forecast.ndim != 2:
-            raise DataValidationError(
-                f"Z_forecast must be 2D numpy array, got shape {Z_forecast.shape if isinstance(Z_forecast, np.ndarray) else 'not array'}"
-            )
-        if not isinstance(C, np.ndarray) or C.ndim != 2:
-            raise DataValidationError(
-                f"C must be 2D numpy array, got shape {C.shape if isinstance(C, np.ndarray) else 'not array'}"
-            )
-        
-        horizon, m = Z_forecast.shape
-        N, m_C = C.shape
-        
-        if m != m_C:
-            raise DataValidationError(
-                f"Shape mismatch: Z_forecast has {m} factors, but C has {m_C} factors"
-            )
-        
-        validate_no_nan_inf(Z_forecast, name="Z_forecast")
-        validate_no_nan_inf(C, name="loading matrix C")
-        
-        if Wx is not None:
-            if not isinstance(Wx, np.ndarray) or Wx.ndim != 1:
-                raise DataValidationError(
-                    f"Wx must be 1D numpy array, got shape {Wx.shape if isinstance(Wx, np.ndarray) else 'not array'}"
-                )
-            if Wx.shape[0] != N:
-                raise DataValidationError(
-                    f"Wx must have {N} elements (matches C.shape[0]), got {Wx.shape[0]}"
-                )
-            validate_no_nan_inf(Wx, name="Wx")
-        
-        if Mx is not None:
-            if not isinstance(Mx, np.ndarray) or Mx.ndim != 1:
-                raise DataValidationError(
-                    f"Mx must be 1D numpy array, got shape {Mx.shape if isinstance(Mx, np.ndarray) else 'not array'}"
-                )
-            if Mx.shape[0] != N:
-                raise DataValidationError(
-                    f"Mx must have {N} elements (matches C.shape[0]), got {Mx.shape[0]}"
-                )
-            validate_no_nan_inf(Mx, name="Mx")
-        try:
-            # Transform factors to observations: X = Z @ C^T
-            X_forecast_std = Z_forecast @ C.T  # (horizon x N)
-            
-            # Validate transformation output
-            validate_no_nan_inf(X_forecast_std, name="X_forecast_std")
-            
-            if X_forecast_std.shape != (horizon, N):
-                raise DataValidationError(
-                    f"Transformation output has unexpected shape {X_forecast_std.shape}, expected ({horizon}, {N})"
-                )
-            
-            # Unstandardize if parameters provided
-            if Wx is not None or Mx is not None:
-                # Handle Wx with shape validation
-                if Wx is not None and len(Wx) != N:
-                    if len(Wx) > N:
-                        Wx_clean = Wx[:N]
-                    else:
-                        Wx_clean = np.ones(N, dtype=np.float64)
-                        Wx_clean[:len(Wx)] = Wx
-                else:
-                    Wx_clean = Wx if Wx is not None else np.ones(N, dtype=np.float64)
-                
-                # Handle Mx with shape validation
-                if Mx is not None and len(Mx) != N:
-                    if len(Mx) > N:
-                        Mx_clean = Mx[:N]
-                    else:
-                        Mx_clean = np.zeros(N, dtype=np.float64)
-                        Mx_clean[:len(Mx)] = Mx
-                else:
-                    Mx_clean = Mx if Mx is not None else np.zeros(N, dtype=np.float64)
-                
-                # Unstandardize: X_original = X_standardized * Wx + Mx
-                X_forecast = X_forecast_std * Wx_clean + Mx_clean
-            else:
-                # No unstandardization
-                X_forecast = X_forecast_std
-            
-            # Validate final output
-            validate_no_nan_inf(X_forecast, name="X_forecast")
-            
-            if X_forecast.shape != (horizon, N):
-                raise DataValidationError(
-                    f"Final forecast output has unexpected shape {X_forecast.shape}, expected ({horizon}, {N})"
-                )
-            
-            return X_forecast
-            
-        except (RuntimeError, ValueError, TypeError, AttributeError, KeyError, IndexError) as e:
-            # Specific exceptions for forecast computation failures
-            if isinstance(e, (DataValidationError, NumericalError)):
-                raise
-            raise NumericalError(
-                f"Factor-to-observation transformation failed: {e}",
-                details=(
-                    f"Z_forecast shape: {Z_forecast.shape}, C shape: {C.shape}, "
-                    f"Wx shape: {Wx.shape if Wx is not None else None}, "
-                    f"Mx shape: {Mx.shape if Mx is not None else None}. "
-                    f"Check: (1) Matrix dimensions, (2) Numerical stability, (3) Input validity."
-                )
-            ) from e
+    # Legacy method removed: _transform_factors_to_observations()
+    # This method used Mx/Wx arrays which are no longer used.
+    # Models now use target_scaler.inverse_transform() directly in their predict() methods.
     
     def _resolve_target_series(
         self,
-        target: Optional[List[str]],
         series_ids: Optional[List[str]] = None,
         result: Optional[BaseResult] = None
     ) -> Tuple[Optional[List[str]], Optional[List[int]]]:
@@ -608,8 +450,6 @@ class BaseFactorModel(ABC):
         
         Parameters
         ----------
-        target : List[str], optional
-            Deprecated. Ignored. Target series are now always taken from DataModule.
         series_ids : List[str], optional
             Available series IDs from config or result. Used for validation.
         result : BaseResult, optional
@@ -624,14 +464,12 @@ class BaseFactorModel(ABC):
             
         Raises
         ------
-        ValueError
-            If target cannot be resolved and is required
         DataError
             If target series are not found in available series
         """
         from ..utils.errors import DataError
         
-        # Get target series from DataModule (target parameter is deprecated)
+        # Get target series from DataModule
         target_series = None
         try:
             data_module = self._get_datamodule()
@@ -643,9 +481,9 @@ class BaseFactorModel(ABC):
         
         # Get series_ids for validation
         if series_ids is None:
-            if result is not None and hasattr(result, 'series_ids'):
-                series_ids = result.series_ids
-            elif self._config is not None:
+            if result is not None:
+                series_ids = getattr(result, 'series_ids', None)
+            if series_ids is None and self._config is not None:
                 series_ids = self._config.get_series_ids()
         
         # Resolve indices if we have both target_series and series_ids
@@ -656,17 +494,16 @@ class BaseFactorModel(ABC):
                 if tgt_id in series_ids:
                     target_indices.append(series_ids.index(tgt_id))
                 else:
-                    # Log warning but continue - user may want partial results
                     _logger.warning(
                         f"{self.__class__.__name__} prediction: target series '{tgt_id}' not found in series_ids. "
-                        f"Available: {series_ids[:10]}{'...' if len(series_ids) > 10 else ''}. "
+                        f"Available: {series_ids[:MAX_WARNING_ITEMS]}{'...' if len(series_ids) > MAX_WARNING_ITEMS else ''}. "
                         f"Skipping this target series."
                     )
             
             if len(target_indices) == 0:
                 raise DataError(
                     f"{self.__class__.__name__} prediction failed: none of the specified target series found",
-                    details=f"Target: {target_series}, Available: {series_ids[:20]}{'...' if len(series_ids) > 20 else ''}"
+                    details=f"Target: {target_series}, Available: {series_ids[:MAX_ERROR_ITEMS]}{'...' if len(series_ids) > MAX_ERROR_ITEMS else ''}"
                 )
         
         return target_series, target_indices
@@ -678,7 +515,7 @@ class BaseFactorModel(ABC):
         ----------
         default : int, optional
             Default value to use if clock frequency cannot be determined.
-            If None, uses 12 periods.
+            If None, uses DEFAULT_FORECAST_HORIZON constant.
             
         Returns
         -------
@@ -686,36 +523,7 @@ class BaseFactorModel(ABC):
             Default horizon in periods (typically 1 year worth of periods)
         """
         if default is None:
-            default = 12
-        
-        try:
-            from ..config import get_periods_per_year
-            from ..utils.misc import get_clock_frequency
-            
-            if self._config is not None:
-                clock = get_clock_frequency(self._config)
-                return get_periods_per_year(clock)
-        except (AttributeError, ImportError, ValueError):
-            _logger.debug(f"Could not determine horizon from clock frequency, using default={default}")
-        
-        return default
-    
-    def _compute_default_horizon(self, default: Optional[int] = None) -> int:
-        """Compute default forecast horizon from clock frequency.
-        
-        Parameters
-        ----------
-        default : int, optional
-            Default value to use if clock frequency cannot be determined.
-            If None, uses 12 periods.
-            
-        Returns
-        -------
-        int
-            Default horizon in periods (typically 1 year worth of periods)
-        """
-        if default is None:
-            default = 12
+            default = DEFAULT_FORECAST_HORIZON
         
         try:
             from ..config import get_periods_per_year
@@ -731,89 +539,40 @@ class BaseFactorModel(ABC):
     
     
     @staticmethod
-    @staticmethod
-    def _clean_mx_wx(
-        Mx: Optional[np.ndarray],
-        Wx: Optional[np.ndarray],
+    def _create_default_standardization_arrays(
         n_series: int,
         dtype: Optional[type] = None
     ) -> Tuple[np.ndarray, np.ndarray]:
-        """Clean Mx/Wx arrays by replacing NaN with defaults.
+        """Create default standardization arrays (for internal use only).
         
-        This helper consolidates the common pattern of cleaning Mx/Wx arrays
-        that may contain NaN values or be None. Used consistently across DFM,
-        DDFM, and KDFM models for standardizing data preprocessing.
+        Creates arrays representing standardized data (mean=0, std=1).
+        Used internally when data is already standardized and no scaler is provided.
         
         Parameters
         ----------
-        Mx : np.ndarray, optional
-            Mean values array (may contain NaN or be None)
-        Wx : np.ndarray, optional
-            Standard deviation values array (may contain NaN or be None)
         n_series : int
-            Number of series (for creating default arrays)
+            Number of series
         dtype : type, optional
             Data type for arrays. If None, uses DEFAULT_DTYPE.
             
         Returns
         -------
         Tuple[np.ndarray, np.ndarray]
-            Cleaned (Mx_clean, Wx_clean) arrays with NaN replaced by defaults.
-            Mx_clean: mean values (default 0.0), Wx_clean: std values (default 1.0)
-            
-        Examples
-        --------
-        >>> Mx = np.array([1.0, np.nan, 2.0])
-        >>> Wx = np.array([0.5, np.nan, 1.0])
-        >>> Mx_clean, Wx_clean = BaseFactorModel._clean_mx_wx(Mx, Wx, n_series=3)
-        >>> assert np.allclose(Mx_clean, [1.0, 0.0, 2.0])
-        >>> assert np.allclose(Wx_clean, [0.5, 1.0, 1.0])
+            (mean_array, std_array) both of shape (n_series,)
+            mean_array: zeros (standardized data has zero mean)
+            std_array: ones (standardized data has unit variance)
         """
-        from ..config.constants import DEFAULT_DTYPE
         if dtype is None:
             dtype = DEFAULT_DTYPE
         
-        # Constants for default values
-        from ..config.constants import DEFAULT_WX_VALUE, DEFAULT_MX_VALUE
+        mean_array = np.zeros(n_series, dtype=dtype)
+        std_array = np.ones(n_series, dtype=dtype)
         
-        # Clean Wx: replace NaN with default, or create default array if None
-        if Wx is not None:
-            Wx_clean = np.where(np.isnan(Wx), DEFAULT_WX_VALUE, Wx).astype(dtype)
-        else:
-            Wx_clean = np.ones(n_series, dtype=dtype) * DEFAULT_WX_VALUE
-        
-        # Clean Mx: replace NaN with default, or create default array if None
-        if Mx is not None:
-            Mx_clean = np.where(np.isnan(Mx), DEFAULT_MX_VALUE, Mx).astype(dtype)
-        else:
-            Mx_clean = np.zeros(n_series, dtype=dtype)
-        
-        return Mx_clean, Wx_clean
+        return mean_array, std_array
     
-    def _standardize_data(self, X: np.ndarray, Mx: Optional[np.ndarray], Wx: Optional[np.ndarray]) -> np.ndarray:
-        """Standardize data using mean and standard deviation.
-        
-        Parameters
-        ----------
-        X : np.ndarray
-            Data matrix (T x N)
-        Mx : np.ndarray, optional
-            Mean values (N,)
-        Wx : np.ndarray, optional
-            Standard deviation values (N,)
-            
-        Returns
-        -------
-        np.ndarray
-            Standardized data (T x N)
-        """
-        if Mx is not None and Wx is not None:
-            # Standardize: X_std = (X - Mx) / Wx
-            # Use 1.0 as default when Wx is zero (avoid division by zero)
-            DEFAULT_WX_FALLBACK = 1.0
-            X_std = (X - Mx) / np.where(Wx != 0, Wx, DEFAULT_WX_FALLBACK)
-            return X_std
-        return X
+    # Legacy method removed: _standardize_data()
+    # This method used Mx/Wx arrays which are no longer used.
+    # Data standardization should be done using sklearn scalers before passing to models.
     
     def reset(self) -> 'BaseFactorModel':
         """Reset model state."""
