@@ -12,11 +12,13 @@ if TYPE_CHECKING:
     from ..functional.em import EMConfig
 
 from ..logger import get_logger
+from ..utils.errors import ConfigurationError, DataValidationError
 from ..config.constants import (
     MIN_DIAGONAL_VARIANCE,
     MIN_FACTOR_VARIANCE,
     DEFAULT_REGULARIZATION,
     MIN_EIGENVALUE,
+    MIN_STD,
     VAR_STABILITY_THRESHOLD,
     AR_CLIP_MIN,
     AR_CLIP_MAX,
@@ -27,6 +29,8 @@ from ..config.constants import (
     DEFAULT_ZERO_VALUE,
     DEFAULT_PROCESS_NOISE,
     DEFAULT_TRANSITION_COEF,
+    DEFAULT_VARIANCE_FALLBACK,
+    DEFAULT_MIN_OBS,
 )
 from .stability import (
     clean_matrix,
@@ -42,9 +46,7 @@ from ..utils.helper import handle_linear_algebra_error, get_config_attr
 
 _logger = get_logger(__name__)
 
-# Numerical stability constants
-MIN_VARIANCE_COVARIANCE = MIN_FACTOR_VARIANCE
-DEFAULT_VARIANCE_FALLBACK = 1.0
+# Note: MIN_VARIANCE_COVARIANCE is defined in stability.py to avoid duplication
 
 
 # ============================================================================
@@ -92,7 +94,7 @@ def clip_ar(
         'max_violations': int(np.sum(above_max))
     }
     if warn and n_clipped > 0:
-        pct_clipped = 100.0 * n_clipped / n_total if n_total > 0 else 0.0
+        pct_clipped = 100.0 * n_clipped / n_total if n_total > 0 else DEFAULT_ZERO_VALUE
         _logger.warning(
             f"AR coefficient clipping applied: {n_clipped}/{n_total} ({pct_clipped:.1f}%) "
             f"coefficients clipped to [{min_val}, {max_val}]."
@@ -123,179 +125,78 @@ def apply_ar_clipping(
     if config is None:
         return clip_ar(A, AR_CLIP_MIN, AR_CLIP_MAX, True)
     
-    clip_enabled = get_config_attr(config, 'clip_ar_coefficients', True)
-    if not clip_enabled:
+    # Check new consolidated ar_clip parameter
+    ar_clip = get_config_attr(config, 'ar_clip', None)
+    if ar_clip is None:
+        # No clipping if ar_clip is None
         return A, {'n_clipped': 0, 'n_total': A.size, 'clipped_indices': []}
     
-    min_val = get_config_attr(config, 'ar_clip_min', AR_CLIP_MIN)
-    max_val = get_config_attr(config, 'ar_clip_max', AR_CLIP_MAX)
-    warn = get_config_attr(config, 'warn_on_ar_clip', True)
-    return clip_ar(A, min_val, max_val, warn)
-
-
-def estimate_ar(
-    EZZ_FB: np.ndarray,
-    EZZ_BB: np.ndarray,
-    vsmooth_sum: Optional[np.ndarray] = None
-) -> Tuple[np.ndarray, Optional[np.ndarray]]:
-    """Estimate AR coefficients and innovation variances from expectations.
+    # Extract min/max from dict
+    if not isinstance(ar_clip, dict):
+        raise ValueError(f"ar_clip must be a dict with 'min' and 'max' keys, got {type(ar_clip)}")
     
-    Parameters
-    ----------
-    EZZ_FB : np.ndarray
-        Forward-backward expectation E[z_t z_{t-1}']
-    EZZ_BB : np.ndarray
-        Backward-backward expectation E[z_{t-1} z_{t-1}']
-    vsmooth_sum : np.ndarray, optional
-        Sum of smoothing variances
-        
-    Returns
-    -------
-    A_diag : np.ndarray
-        AR coefficients (diagonal)
-    Q_diag : np.ndarray or None
-        Innovation variances (diagonal, currently None)
-    """
-    if np.isscalar(EZZ_FB):
-        EZZ_FB = np.array([EZZ_FB])
-        EZZ_BB = np.array([EZZ_BB])
-    if EZZ_FB.ndim > 1:
-        EZZ_FB_diag = np.diag(EZZ_FB).copy()
-        EZZ_BB_diag = np.diag(EZZ_BB).copy()
-    else:
-        EZZ_FB_diag = EZZ_FB.copy()
-        EZZ_BB_diag = EZZ_BB.copy()
-    if vsmooth_sum is not None:
-        if vsmooth_sum.ndim > 1:
-            vsmooth_diag = np.diag(vsmooth_sum)
-        else:
-            vsmooth_diag = vsmooth_sum
-        EZZ_BB_diag = EZZ_BB_diag + vsmooth_diag
-    min_denom = np.maximum(np.abs(EZZ_BB_diag) * MIN_DIAGONAL_VARIANCE, MIN_VARIANCE_COVARIANCE)
-    EZZ_BB_diag = np.where(
-        (np.isnan(EZZ_BB_diag) | np.isinf(EZZ_BB_diag) | (np.abs(EZZ_BB_diag) < min_denom)),
-        min_denom, EZZ_BB_diag
-    )
-    # Use clean_matrix for consistency
-    if EZZ_FB_diag.ndim == 0:
-        EZZ_FB_diag_clean = clean_matrix(np.array([EZZ_FB_diag]), 'general', default_nan=DEFAULT_CLEAN_NAN, default_inf=DEFAULT_CLEAN_INF)
-        EZZ_FB_diag = EZZ_FB_diag_clean[0] if EZZ_FB_diag_clean.size > 0 else DEFAULT_ZERO_VALUE
-    else:
-        EZZ_FB_diag = clean_matrix(EZZ_FB_diag, 'general', default_nan=DEFAULT_CLEAN_NAN, default_inf=DEFAULT_CLEAN_INF)
-    A_diag = EZZ_FB_diag / EZZ_BB_diag
-    # Q_diag is not computed here (returns None for compatibility)
-    Q_diag: Optional[np.ndarray] = None
-    return A_diag, Q_diag
+    min_val = ar_clip.get('min', AR_CLIP_MIN)
+    max_val = ar_clip.get('max', AR_CLIP_MAX)
+    
+    # Always warn when clipping is enabled (ar_clip is not None)
+    return clip_ar(A, min_val, max_val, warn=True)
 
 
+# Removed estimate_ar - unused function
+
 def estimate_var(factors: np.ndarray, order: int = 1) -> Tuple[np.ndarray, np.ndarray]:
-    """Estimate VAR dynamics for factors.
-    
-    Supports VAR(1) and VAR(2) estimation. VAR(2) is the maximum supported order.
+    """Estimate AR(1) dynamics for factors.
     
     Parameters
     ----------
     factors : np.ndarray
         Extracted factors (T x m)
     order : int, default 1
-        VAR order (1 or 2)
+        AR order (always 1)
         
     Returns
     -------
     A : np.ndarray
-        Transition matrix (m x m) for order=1, or (m x 2m) = [A1, A2] for order=2
+        Transition matrix (m x m) for AR(1)
     Q : np.ndarray
         Innovation covariance (m x m)
-        
-    Raises
-    ------
-    ValueError
-        If order is not 1 or 2
     """
-    if order not in (1, 2):
-        raise ValueError(f"VAR order must be 1 or 2, got {order}")
-    
     T, m = factors.shape
     
-    if order == 1:
-        if T < 2:
-            # Not enough data, use identity
-            A = create_scaled_identity(m, DEFAULT_IDENTITY_SCALE)
-            Q = create_scaled_identity(m, DEFAULT_PROCESS_NOISE)
-            return A, Q
-        
-        # Prepare data for OLS: f_t = A @ f_{t-1}
-        Y = factors[1:, :]  # T-1 x m (dependent)
-        X = factors[:-1, :]  # T-1 x m (independent)
-        
-        # OLS: A = (X'X)^{-1} X'Y
-        A = solve_regularized_ols(X, Y, regularization=DEFAULT_REGULARIZATION).T
-        
-        # Ensure stability: clip eigenvalues
-        eigenvals = np.linalg.eigvals(A)
-        max_eigenval = np.max(np.abs(eigenvals))
-        if max_eigenval >= VAR_STABILITY_THRESHOLD:
-            A = A * (VAR_STABILITY_THRESHOLD / max_eigenval)
-        
-        # Estimate innovation covariance
-        residuals = Y - X @ A.T
-        Q = compute_cov_safe(residuals.T, rowvar=True, pairwise_complete=False)
-        
-        # Stabilize Q: symmetrize, ensure positive definite, apply floor
-        Q = stabilize_innovation_covariance(Q, min_eigenval=MIN_EIGENVALUE, min_floor=MIN_Q_FLOOR, dtype=np.float32)
-        
+    if T < 2:
+        # Not enough data, use identity
+        A = create_scaled_identity(m, DEFAULT_IDENTITY_SCALE)
+        Q = create_scaled_identity(m, DEFAULT_PROCESS_NOISE)
         return A, Q
     
-    else:  # order == 2
-        if T < 3:
-            # Not enough data, use VAR(1) fallback
-            _logger.warning(
-                f"Insufficient data (T={T}) for VAR(2). Falling back to VAR(1)."
-            )
-            A1, Q = estimate_var(factors, order=1)
-            # Pad A to VAR(2) format: [A1, A2] where A2 = 0
-            A = np.hstack([A1, np.zeros((A1.shape[0], A1.shape[1]))])
-            return A, Q
-        
-        # Prepare data for VAR(2): f_t = A1 @ f_{t-1} + A2 @ f_{t-2}
-        Y = factors[2:, :]  # T-2 x m (dependent)
-        X = np.hstack((factors[1:-1, :], factors[:-2, :]))  # T-2 x 2m (independent)
-        
-        # OLS: A = (X'X)^{-1} X'Y, where A = [A1, A2]
-        A = solve_regularized_ols(X, Y, regularization=DEFAULT_REGULARIZATION).T
-        
-        # Split into A1 and A2
-        A1 = A[:, :m]
-        A2 = A[:, m:]
-        
-        # Ensure stability: check eigenvalues of companion form
-        companion = np.block([
-            [A1, A2],
-            [create_scaled_identity(m, DEFAULT_IDENTITY_SCALE), np.zeros((m, m))]
-        ])
-        eigenvals = np.linalg.eigvals(companion)
-        max_eigenval = np.max(np.abs(eigenvals))
-        if max_eigenval >= VAR_STABILITY_THRESHOLD:
-            scale = VAR_STABILITY_THRESHOLD / max_eigenval
-            A1 = A1 * scale
-            A2 = A2 * scale
-            A = np.hstack((A1, A2))
-        
-        # Estimate innovation covariance
-        residuals = Y - X @ A.T
-        Q = compute_cov_safe(residuals.T, rowvar=True, pairwise_complete=False)
-        
-        # Stabilize Q: symmetrize, ensure positive definite, apply floor
-        Q = stabilize_innovation_covariance(Q, min_eigenval=MIN_EIGENVALUE, min_floor=MIN_Q_FLOOR, dtype=np.float32)
-        
-        return A, Q
+    # Prepare data for OLS: f_t = A @ f_{t-1}
+    Y = factors[1:, :]  # T-1 x m (dependent)
+    X = factors[:-1, :]  # T-1 x m (independent)
+    
+    # OLS: A = (X'X)^{-1} X'Y
+    A = solve_regularized_ols(X, Y, regularization=DEFAULT_REGULARIZATION).T
+    
+    # Ensure stability: clip eigenvalues
+    eigenvals = np.linalg.eigvals(A)
+    max_eigenval = np.max(np.abs(eigenvals))
+    if max_eigenval >= VAR_STABILITY_THRESHOLD:
+        A = A * (VAR_STABILITY_THRESHOLD / max_eigenval)
+    
+    # Estimate innovation covariance
+    residuals = Y - X @ A.T
+    Q = compute_cov_safe(residuals.T, rowvar=True, pairwise_complete=False)
+    
+    # Stabilize Q: symmetrize, ensure positive definite, apply floor
+    Q = stabilize_innovation_covariance(Q, min_eigenval=MIN_EIGENVALUE, min_floor=MIN_Q_FLOOR, dtype=np.float32)
+    
+    return A, Q
 
 
 
 def estimate_idio_dynamics(
     residuals: np.ndarray,
     missing_mask: np.ndarray,
-    min_obs: int = 5,
+    min_obs: int = DEFAULT_MIN_OBS,
 ) -> Tuple[np.ndarray, np.ndarray]:
     """Estimate AR(1) dynamics for idiosyncratic components.
     
@@ -305,7 +206,7 @@ def estimate_idio_dynamics(
         Residuals from observation equation (T x N)
     missing_mask : np.ndarray
         Missing data mask (T x N), True where data is missing
-    min_obs : int, default 5
+    min_obs : int, default DEFAULT_MIN_OBS
         Minimum number of observations required for estimation
         
     Returns
@@ -356,7 +257,7 @@ def estimate_idio_dynamics(
                         f"AR(1) coefficient for series {j} clipped to {A_eps[j, j]:.4f} for stability"
                     )
             else:
-                A_eps[j, j] = 0.0
+                A_eps[j, j] = DEFAULT_ZERO_VALUE
             
             # Estimate innovation covariance
             residuals_ar = eps_t - A_eps[j, j] * eps_t_1
@@ -368,7 +269,7 @@ def estimate_idio_dynamics(
 def estimate_idio_params(
     eps: np.ndarray,
     idx_no_missings: Optional[np.ndarray] = None,
-    min_obs: int = 5,
+    min_obs: int = DEFAULT_MIN_OBS,
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     """Estimate AR(1) parameters for idiosyncratic components.
     
@@ -382,7 +283,7 @@ def estimate_idio_params(
         Idiosyncratic residuals (T x N)
     idx_no_missings : np.ndarray, optional
         Boolean mask (T x N) indicating non-missing values
-    min_obs : int, default 5
+    min_obs : int, default DEFAULT_MIN_OBS
         Minimum number of observations required
         
     Returns
@@ -416,7 +317,7 @@ def estimate_idio_params(
         
         mu_eps[j] = float(np.mean(observed))
         std_eps_j = float(np.std(observed))
-        std_eps[j] = max(std_eps_j, 1e-8)
+        std_eps[j] = max(std_eps_j, MIN_STD)
         
         valid_pairs = mask[:-1] & mask[1:]
         pair_count = int(np.sum(valid_pairs))
@@ -444,8 +345,8 @@ def estimate_idio_params(
         from ..config.constants import MAX_WARNING_ITEMS
         preview = ", ".join(f"{idx}:{cnt}" for idx, cnt in insufficient_series[:MAX_WARNING_ITEMS])
         more = ""
-        if len(insufficient_series) > 5:
-            more = f", ... (+{len(insufficient_series) - 5} more)"
+        if len(insufficient_series) > MAX_WARNING_ITEMS:
+            more = f", ... (+{len(insufficient_series) - MAX_WARNING_ITEMS} more)"
         _logger.warning(
             "Falling back to zero AR coefficients for %d series (insufficient observations). "
             "Series indices and available pairs: %s%s",
@@ -457,137 +358,7 @@ def estimate_idio_params(
     return phi, mu_eps, std_eps
 
 
-def estimate_state_space_params(
-    f_t: np.ndarray,
-    eps_t: np.ndarray,
-    factor_order: int,
-    bool_no_miss: Optional[np.ndarray] = None,
-) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
-    """Estimate state-space transition parameters from factors and residuals.
-    
-    Estimates the transition matrix A, innovation covariance W, initial mean mu_0,
-    initial covariance Σ_0, and latent states x_t for the companion form state-space
-    representation.
-    
-    Parameters
-    ----------
-    f_t : np.ndarray
-        Common factors (T x m)
-    eps_t : np.ndarray
-        Idiosyncratic terms (T x N)
-    factor_order : int
-        Lag order for common factors. Only VAR(1) and VAR(2) are supported.
-    bool_no_miss : np.ndarray, optional
-        Boolean array (T x N) indicating non-missing values.
-        If None, assumes no missing values.
-        
-    Returns
-    -------
-    A : np.ndarray
-        Transition matrix (state_dim x state_dim) in companion form
-    W : np.ndarray
-        Innovation covariance matrix (state_dim x state_dim), diagonal
-    mu_0 : np.ndarray
-        Unconditional mean of initial state (state_dim,)
-    Σ_0 : np.ndarray
-        Unconditional covariance of initial state (state_dim x state_dim)
-    x_t : np.ndarray
-        Latent states (state_dim x T) in companion form
-    """
-    T, m = f_t.shape
-    T_eps, N = eps_t.shape
-    
-    if T != T_eps:
-        raise ValueError(f"Time dimension mismatch: f_t has {T} timesteps, eps_t has {T_eps}")
-    
-    # Estimate factor dynamics (VAR)
-    if factor_order == 2:
-        if T < 3:
-            raise ValueError("Insufficient data for VAR(2). Need at least 3 timesteps.")
-        f_past = np.hstack((f_t[1:-1, :], f_t[:-2, :]))  # (T-2) x 2m
-        f_future = f_t[2:, :]  # (T-2) x m
-        # OLS: A_f = (f_past' @ f_past)^{-1} @ f_past' @ f_future
-        A_f = solve_regularized_ols(f_past, f_future, regularization=DEFAULT_REGULARIZATION).T
-        # Split into A1 and A2
-        A1 = A_f[:, :m]  # m x m
-        A2 = A_f[:, m:]  # m x m
-    elif factor_order == 1:
-        if T < 2:
-            raise ValueError("Insufficient data for VAR(1). Need at least 2 timesteps.")
-        f_past = f_t[:-1, :]  # (T-1) x m
-        f_future = f_t[1:, :]  # (T-1) x m
-        # OLS: A_f = (f_past' @ f_past)^{-1} @ f_past' @ f_future
-        A_f = solve_regularized_ols(f_past, f_future, regularization=DEFAULT_REGULARIZATION).T
-        A1 = A_f
-        A2 = np.zeros((m, m))  # VAR(1) doesn't use A2, but set to zeros for consistency
-    else:
-        raise NotImplementedError(
-            f"Only VAR(1) or VAR(2) for common factors are supported (maximum supported order is VAR(2)). "
-            f"Got factor_order={factor_order}. Please use factor_order=1 (VAR(1)) or factor_order=2 (VAR(2))"
-        )
-    
-    # Estimate idiosyncratic AR(1) dynamics
-    A_eps, _, _ = estimate_idio_params(eps_t, bool_no_miss, min_obs=5)
-    
-    # Construct companion form state vector and transition matrix
-    if factor_order == 2:
-        # x_t = [f_t, f_{t-1}, eps_t]
-        x_t = np.vstack([
-            f_t[1:, :].T,  # m x (T-1)
-            f_t[:-1, :].T,  # m x (T-1)
-            eps_t[1:, :].T  # N x (T-1)
-        ])  # (2m + N) x (T-1)
-        
-        # Transition matrix in companion form
-        A = np.vstack([
-            np.hstack([A1, A2, np.zeros((m, N))]),  # f_t = A1 @ f_{t-1} + A2 @ f_{t-2}
-            np.hstack([np.eye(m), np.zeros((m, m)), np.zeros((m, N))]),  # f_{t-1} = f_{t-1}
-            np.hstack([np.zeros((N, m)), np.zeros((N, m)), A_eps])  # eps_t = A_eps @ eps_{t-1}
-        ])
-    else:  # factor_order == 1
-        # x_t = [f_t, eps_t]
-        x_t = np.vstack([
-            f_t.T,  # m x T
-            eps_t.T  # N x T
-        ])  # (m + N) x T
-        
-        # Transition matrix
-        A = np.vstack([
-            np.hstack([A1, np.zeros((m, N))]),  # f_t = A1 @ f_{t-1}
-            np.hstack([np.zeros((N, m)), A_eps])  # eps_t = A_eps @ eps_{t-1}
-        ])
-    
-    # Estimate innovation covariance (diagonal)
-    # w_t = x_t[:, 1:] - A @ x_t[:, :-1]
-    w_t = x_t[:, 1:] - A @ x_t[:, :-1]
-    W_cov = compute_cov_safe(w_t, rowvar=False, pairwise_complete=False)
-    W = np.diag(np.diag(W_cov))
-    # Ensure positive diagonal
-    W = np.maximum(W, np.eye(W.shape[0]) * MIN_DIAGONAL_VARIANCE)
-    
-    # Unconditional moments of initial state
-    mu_0 = np.mean(x_t, axis=1)
-    Σ_0 = compute_cov_safe(x_t, rowvar=False, pairwise_complete=False)
-    
-    # Enforce zero correlation between factors and idiosyncratic components
-    if factor_order == 2:
-        factor_dim = 2 * m
-    else:
-        factor_dim = m
-    
-    Σ_0[:factor_dim, factor_dim:] = 0
-    Σ_0[factor_dim:, :factor_dim] = 0
-    # Ensure diagonal covariance for idiosyncratic components
-    Σ_0[factor_dim:, factor_dim:] = np.diag(np.diag(Σ_0[factor_dim:, factor_dim:]))
-    
-    # Ensure positive semidefinite
-    from .stability import ensure_positive_definite
-    eigenvals = np.linalg.eigvals(Σ_0)
-    if np.any(eigenvals < 0):
-        Σ_0 = Σ_0 + np.eye(Σ_0.shape[0]) * (MIN_DIAGONAL_VARIANCE - np.min(eigenvals))
-    
-    return A, W, mu_0, Σ_0, x_t
-
+# Removed estimate_state_space_params - unused function
 
 # ============================================================================
 # Unified Estimation Functions (work with raw data or smoothed expectations)
@@ -661,7 +432,7 @@ def estimate_var_unified(
                 EZZ_FB = EZZ_FB + VVsmooth
         
         # Regularize
-        EZZ_BB_reg = EZZ_BB + np.eye(p, dtype=dtype) * regularization
+        EZZ_BB_reg = EZZ_BB + create_scaled_identity(p, regularization, dtype=dtype)
         
         def _compute_A_Q():
             # OLS: A = (EZZ_BB)^(-1) @ EZZ_FB'
@@ -693,8 +464,10 @@ def estimate_var_unified(
         p = x.shape[1]
         
         if T < 2:
+            # For rectangular matrix (m x p), use np.eye directly (create_scaled_identity only supports square)
+            # Note: A is rectangular (m x p), so cannot use create_scaled_identity
             A = np.eye(m, p, dtype=dtype) * DEFAULT_TRANSITION_COEF
-            Q = np.eye(m, dtype=dtype) * DEFAULT_PROCESS_NOISE
+            Q = create_scaled_identity(m, DEFAULT_PROCESS_NOISE, dtype=dtype)
             return A, Q
         
         # OLS: A = (X'X + reg*I)^(-1) X'Y
@@ -823,7 +596,7 @@ def estimate_ar1_unified(
             try:
                 # OLS: A = (x'x + reg)^(-1) x'y
                 XTX = x_i_clean.T @ x_i_clean
-                XTX_reg = XTX + np.eye(1, dtype=dtype) * regularization
+                XTX_reg = XTX + create_scaled_identity(1, regularization, dtype=dtype)
                 A_i = np.linalg.solve(XTX_reg, x_i_clean.T @ y_i_clean).item()
                 
                 # Estimate Q from residuals
@@ -885,10 +658,10 @@ def estimate_constrained_ols_unified(
         
         # Apply constraints: beta_constrained = beta_unconstrained - X^(-1) @ R' @ (R @ X^(-1) @ R')^(-1) @ (R @ beta_unconstrained - q)
         try:
-            X_reg = X + np.eye(X.shape[0], dtype=dtype) * regularization
+            X_reg = X + create_scaled_identity(X.shape[0], regularization, dtype=dtype)
             X_inv = np.linalg.inv(X_reg)
             R_X_inv_RT = R @ X_inv @ R.T
-            R_X_inv_RT_reg = R_X_inv_RT + np.eye(R_X_inv_RT.shape[0], dtype=dtype) * regularization
+            R_X_inv_RT_reg = R_X_inv_RT + create_scaled_identity(R_X_inv_RT.shape[0], regularization, dtype=dtype)
             constraint_term = R @ beta_unconstrained - q
             beta_constrained = beta_unconstrained - X_inv @ R.T @ np.linalg.solve(R_X_inv_RT_reg, constraint_term)
         except (np.linalg.LinAlgError, ValueError):
@@ -901,10 +674,10 @@ def estimate_constrained_ols_unified(
         # Apply constraints
         try:
             XTX = X.T @ X
-            XTX_reg = XTX + np.eye(XTX.shape[0], dtype=dtype) * regularization
+            XTX_reg = XTX + create_scaled_identity(XTX.shape[0], regularization, dtype=dtype)
             XTX_inv = np.linalg.inv(XTX_reg)
             R_XTX_inv_RT = R @ XTX_inv @ R.T
-            R_XTX_inv_RT_reg = R_XTX_inv_RT + np.eye(R_XTX_inv_RT.shape[0], dtype=dtype) * regularization
+            R_XTX_inv_RT_reg = R_XTX_inv_RT + create_scaled_identity(R_XTX_inv_RT.shape[0], regularization, dtype=dtype)
             constraint_term = R @ beta_unconstrained - q
             beta_constrained = beta_unconstrained - XTX_inv @ R.T @ np.linalg.solve(R_XTX_inv_RT_reg, constraint_term)
         except (np.linalg.LinAlgError, ValueError):
@@ -954,7 +727,7 @@ def estimate_variance_unified(
         T, N = residuals.shape
         
         if T <= 1:
-            R = np.eye(N, dtype=dtype) * default_variance
+            R = create_scaled_identity(N, default_variance, dtype=dtype)
             return R
         
         # Compute variance for each series
@@ -975,7 +748,10 @@ def estimate_variance_unified(
     else:
         # Smoothed expectations mode
         if X is None or EZ is None or C is None:
-            raise ValueError("X, EZ, and C are required for smoothed expectations mode")
+            raise ConfigurationError(
+                "X, EZ, and C are required for smoothed expectations mode",
+                details=f"Missing required parameters: X={X is None}, EZ={EZ is None}, C={C is None}"
+            )
         
         T, N = X.shape
         m = EZ.shape[1]
@@ -1038,9 +814,9 @@ def compute_initial_covariance_from_transition(
     n = A.shape[0]
     try:
         kron_AA = np.kron(A, A)
-        eye_kron = np.eye(n ** 2, dtype=dtype)
+        eye_kron = create_scaled_identity(n ** 2, DEFAULT_IDENTITY_SCALE, dtype=dtype)
         V_0_flat = np.linalg.solve(
-            eye_kron - kron_AA + eye_kron * regularization,
+            eye_kron - kron_AA + create_scaled_identity(n ** 2, regularization, dtype=dtype),
             Q.flatten()
         )
         V_0 = V_0_flat.reshape(n, n).astype(dtype)
@@ -1059,11 +835,9 @@ __all__ = [
     'clip_ar',
     'apply_ar_clipping',
     # Estimation functions
-    'estimate_ar',
     'estimate_var',
     'estimate_idio_dynamics',
     'estimate_idio_params',
-    'estimate_state_space_params',
     # Unified estimation functions
     'estimate_var_unified',
     'estimate_ar1_unified',
