@@ -19,7 +19,6 @@ from ..numeric.builder import (
 from ..numeric.estimator import (
     estimate_var,
     estimate_idio_dynamics,
-    estimate_state_space_params,
 )
 
 # Time utilities
@@ -132,6 +131,7 @@ try:
         ensure_numpy,
         validate_matrix_shape,
         log_tensor_stats,
+        select_columns_by_prefix,
     )
 except ImportError:
     # Common utilities may not be available in all versions
@@ -139,6 +139,7 @@ except ImportError:
     ensure_numpy = None
     validate_matrix_shape = None
     log_tensor_stats = None
+    select_columns_by_prefix = None
 
 # Analytics utilities (moved from common.py and model_helpers.py, now in numeric.stability)
 try:
@@ -181,7 +182,6 @@ except ImportError:
 # Helper utilities (from misc)
 from .misc import (
     resolve_param,
-    check_finite_array,
     get_clock_frequency,
     DFMError,
     # Removed exception aliases - use DFMError or proper exceptions from errors.py
@@ -221,7 +221,6 @@ __all__ = [
     'estimate_idio_dynamics',
     'build_observation_matrix',
     'build_state_space',
-    'estimate_state_space_params',
     # Time utilities (includes metrics)
     'calculate_rmse',
     'calculate_mae',
@@ -246,7 +245,6 @@ __all__ = [
     'detect_config_type',
     # Helper utilities
     'resolve_param',
-    'check_finite_array',
     'get_clock_frequency',
     # Exception classes
     'DFMError',
@@ -284,6 +282,7 @@ __all__ = [
     'extract_matrix_block',
     'validate_matrix_shape',
     'log_tensor_stats',
+    'select_columns_by_prefix',
     # Model validation utilities (from numeric.validator)
     'validate_companion_stability',
     'validate_companion_matrix',
